@@ -2,7 +2,7 @@
 
 /* rda_ogon.h - Remote Desktop Awareness for Ogon RDP Sessions
 
-   Copyright (C) 2018 Mike Gabriel
+   Copyright (C) 2018-2019 Mike Gabriel
    All rights reserved.
 
    The RDA Library is free software; you can redistribute it and/or
@@ -24,22 +24,24 @@
 #ifndef RDA_OGON_H
 #define RDA_OGON_H
 
-#include <config.h>
 #include <glib.h>
 
 #include <rda.h>
 
-#ifdef WITH_OGON_AWARENESS
+#ifdef WITH_REMOTE_AWARENESS_OGON
 
 gboolean
 rda_session_is_ogon (void);
 
+gchar *
+rda_remote_technology_name_ogon(void);
+
 gboolean
 rda_session_suspend_ogon (void);
 
 gboolean
 rda_session_terminate_ogon (void);
 
-#endif /* WITH_OGON_AWARENESS */
+#endif /* WITH_REMOTE_AWARENESS_OGON */
 
 #endif /* RDA_OGON_H */
