@@ -2,7 +2,7 @@
 
 /* rda_x2go.h - Remote Desktop Awareness for X2Go Sessions
 
-   Copyright (C) 2018 Mike Gabriel
+   Copyright (C) 2018-2019 Mike Gabriel
    All rights reserved.
 
    The RDA Library is free software; you can redistribute it and/or
@@ -24,22 +24,24 @@
 #ifndef RDA_X2GO_H
 #define RDA_X2GO_H
 
-#include <config.h>
 #include <glib.h>
 
 #include <rda.h>
 
-#ifdef WITH_X2GO_AWARENESS
+#ifdef WITH_REMOTE_AWARENESS_X2GO
 
 gboolean
 rda_session_is_x2go (void);
 
+gchar *
+rda_remote_technology_name_x2go(void);
+
 gboolean
 rda_session_suspend_x2go(void);
 
 gboolean
 rda_session_terminate_x2go(void);
 
-#endif /* WITH_X2GO_AWARENESS */
+#endif /* WITH_REMOTE_AWARENESS_X2GO */
 
 #endif /* RDA_X2GO_H */
